/* -*- C++ -*-
 * LocalReplicaCatalog.cpp
 *
 * Copyright (c) 2002 CERN on behalf of the EU DataGrid.
 * For license conditions see LICENSE file or 
 * http://www.edg.org/license.html
 * 
 */

#ifndef ReplicaLocationIndexFactory_H
#define ReplicaLocationIndexFactory_H 1

#include "EdgReplicaLocationIndex/ReplicaLocationIndex.h"

#include <string>

namespace EdgReplicaLocationIndex {

  /** A ReplicaLocationIndex stores mappings from Logical filenames to
   * Physical fileNames, along with attributes on those fileNames.  It also
   * provides indices for efficient location of the mappings.
   *
   */
  class ReplicaLocationIndexFactory {
  public:

    /** Obtain the ReplicaLocationIndex at a given URL.
     * @param url the URL to look for the catalog
     * @return The catalog.
     * @throws NoSuchLocationIndex if no catalog exists at that URL
     */
    static
    ReplicaLocationIndex* getReplicaLocationIndex(const std::string& url);

#ifdef WITH_WP2_SECURITY
    static
    ReplicaLocationIndex* getReplicaLocationIndex(const std::string& url,
						  char *passphrase,
						  char *credentials,
						  char *cacertdir,
						  char *rseedfile);

    static
    ReplicaLocationIndex* getReplicaLocationIndex(const std::string& url,
						  char *passphrase,
						  char *credentials,
						  char *cacertdir,
						  char *rseedfile,
						  char *role,
						  char *policy,
						  char *defaultRole,
						  char *defaultPolicy);
#endif

  };
}; 

#endif // ReplicaLocationIndexFactory_H

